@@ -22,8 +22,9 @@ from calculate.lib.variables.linux import LinuxDataVars
 from calculate.install.distr import IsoDistributive, DistributiveError
 from calculate.lib.utils.files import listDirectory
 from calculate.lib.datavars import ReadonlyVariable, HumanReadable, \
-    ReadonlyTableVariable, FieldValue, VariableError, Variable
-from calculate.install.variables import system
+    ReadonlyTableVariable, FieldValue, VariableError, Variable, \
+    VariableInterface
+from calculate.install.variables import system, X11, locale
 import builder
 from action import Actions
 
@@ -277,3 +278,63 @@ class VariableClBuilderImageSplash(FieldValue, ReadonlyVariable):
     type = "list"
     source_variable = "cl_builder_image_data"
     column = 9
+
+
+class GrubOptionVariable(VariableInterface):
+    """
+    Опции для настроек grub LiveHDD
+    """
+
+    def uncompatible(self):
+        typemenu = self.Get('cl_builder_livemenu_type')
+        if typemenu == "flash":
+            return _("Unavailable for the USB Flash")
+
+
+class VariableClBuilderX11VideoDrv(GrubOptionVariable,
+                                   X11.VariableOsInstallX11VideoDrv):
+    """
+    Выбор видеодрайвера для LiveHDD
+    """
+    type = "choice"
+
+    def get(self):
+        return self.Get('os_x11_video_drv')
+
+    def check(self, value):
+        pass
+
+    def choice(self):
+        values = (X11.VariableOsInstallX11VideoAvailable.supported +
+                  [self.default_video])
+        return map(lambda x: (x, self.driver_names.get(x, x)), values)
+
+
+class VariableClBuilderLocaleLang(GrubOptionVariable,
+                                  locale.VariableOsInstallLocaleLang):
+    pass
+
+
+class VariableClBuilderTimezone(GrubOptionVariable,
+                                locale.VariableOsInstallClockTimezone):
+    """
+    Выбор часового пояса
+    """
+    locale_varname = "builder.cl_builder_locale_lang"
+
+
+class VariableClBuilderX11Resolution(GrubOptionVariable,
+                                     X11.VariableOsInstallX11Resolution):
+    def choice(self):
+        values = super(VariableClBuilderX11Resolution, self).choice()
+        return [("auto", _("Auto"))] + [(x, x) for x in values]
+
+    def check(self, value):
+        if value != "auto":
+            super(VariableClBuilderX11Resolution, self).check(value)
+
+
+class VariableClBuilderX11Composite(GrubOptionVariable,
+                                    X11.VariableOsInstallX11Composite):
+    def get(self):
+        return self.Get('os_x11_composite')
