@@ -33,6 +33,7 @@ from utils.cl_builder_update import ClBuilderUpdateAction
 from utils.cl_builder_restore import ClBuilderRestoreAction
 from utils.cl_builder_image import ClBuilderImageAction
 from utils.cl_builder_menu import ClBuilderMenuAction
+from calculate.builder.variables.action import Actions
 
 _ = lambda x: x
 from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate
@@ -205,15 +206,15 @@ class Wsdl(WsdlBase):
             # идентификатор метода
             'method_name': Builder.Method.UpdateMenu,
             # категория метода
-            'category': __('Update'),
+            'category': __("Configuration"),
             # заголовок метода
-            'title': __("Update Live-Menu"),
+            'title': __("Configure a Live-Menu"),
             # иконка для графической консоли
             'image': 'format-indent-less-rtl,format-indent-more',
             # метод присутствует в графической консоли
             'gui': True,
             # консольная команда
-            'command': 'cl-update-boot-live',
+            'command': 'cl-setup-boot-live',
             # права для запуска метода
             'rights': ['build'],
             # объект содержащий модули для действия
@@ -233,6 +234,13 @@ class Wsdl(WsdlBase):
                                     normal=(
                                         'cl_builder_livemenu_type',
                                         'cl_builder_livemenu_path',),
+                                    expert=(
+                                        'cl_builder_locale_lang',
+                                        'cl_builder_timezone',
+                                        'cl_builder_x11_video_drv',
+                                        'cl_builder_x11_resolution',
+                                        'cl_builder_x11_composite',
+                                    ),
                                     next_label=_("Perform"))],
             'brief': {'next': __("Perform"),
                       'name': __("Update Live-Menu")},
